@@ -2,14 +2,15 @@ use regex::Regex;
 
 use std::collections::HashMap;
 use std::fs;
+use std::path::Path;
 
-pub fn read_file(
-  path: &str,
+pub fn read_file<P: AsRef<Path>>(
+  path: P,
 ) -> Result<HashMap<String, String>, std::io::Error> {
   let content = fs::read_to_string(path)?;
 
   let variable = Regex::new(
-    r#"^(export )?(?P<key>[0-9A-Z_]+)="?(?P<val>[^"]*)"?$"#,
+    r#"^(export )?(?P<key>[0-9A-Za-z_\-]+)="?(?P<val>[^"]*)"?$"#,
   )
   .unwrap();
 
@@ -18,7 +19,7 @@ pub fn read_file(
   for line in content.lines() {
     if let Some(c) = variable.captures(line) {
       config.insert(
-        c.name("key").unwrap().as_str().to_lowercase(),
+        c.name("key").unwrap().as_str().to_owned(),
         c.name("val").unwrap().as_str().to_owned(),
       );
     }
@@ -27,8 +28,8 @@ pub fn read_file(
   Ok(config)
 }
 
-pub fn read_files(
-  paths: &[&str],
+pub fn read_files<P: AsRef<Path>>(
+  paths: &[P],
 ) -> Result<HashMap<String, String>, std::io::Error> {
   let mut res = HashMap::new();
   for path in paths {
